<?php
/**
 * User Controller
 *
 * This file loads the Plans component in the user panel
 *
 * @author Scrisoft
 * @package Midrub
 * @since 0.0.7.9
 */

// Define the page namespace
namespace MidrubBase\User\Components\Collection\Plans\Controllers;

// Constants
defined('BASEPATH') OR exit('No direct script access allowed');

/*
 * User class loads the Plans view
 * 
 * @author Scrisoft
 * @package Midrub
 * @since 0.0.7.9
 */
class User {
    
    /**
     * Class variables
     *
     * @since 0.0.7.9
     */
    protected $CI, $css_urls_widgets = array(), $js_urls_widgets = array();

    /**
     * Initialise the Class
     *
     * @since 0.0.7.9
     */
    public function __construct() {
        
        // Get codeigniter object instance
        $this->CI =& get_instance();
        
        // Load language
        $this->CI->lang->load( 'plans_user', $this->CI->config->item('language'), FALSE, TRUE, MIDRUB_BASE_USER_COMPONENTS_PLANS );

        // Load Alerts Helper
        $this->CI->load->helper('alerts_helper');
        
    }
    
    /**
     * The public method view loads the app's template
     * 
     * @since 0.0.7.9
     * 
     * @return void
     */
    public function view() {

        // Set the Plans styles
        set_css_urls(array('stylesheet', base_url('assets/base/user/components/collection/plans/styles/css/styles.css?ver=' . MIDRUB_BASE_USER_COMPONENTS_PLANS_VERSION), 'text/css', 'all'));
        
        // Set the Gateways Js
        set_js_urls(array(base_url('assets/user/js/gateways.js?ver=' . MIDRUB_BASE_USER_COMPONENTS_PLANS_VERSION)));

        // Load Plans Model
        $this->CI->load->model('plans');

        // Verify if single page exists
        if ( $this->CI->input->get('p', TRUE) ) {

            switch ( $this->CI->input->get('p', TRUE) ) {

                case 'upgrade':

                    // Set plan's id
                    $plan_id = $this->CI->input->get('plan', TRUE);
                    
                    // Set the gateway
                    $gateway = $this->CI->input->get('gateway', TRUE);
                
                    // Verify if plan exists
                    if ( is_numeric( $plan_id ) ) {

                        // Get plan
                        $plan = $this->CI->plans->get_plan($plan_id);

                        // Verify if plan exists
                        if ( $plan ) {

                            // Get plan price
                            $price = $this->CI->plans->get_plan_price($plan_id);

                            if ($price[0]->plan_price > 0) {

                                // Require the Payments interface
                                require_once APPPATH . 'interfaces/Payments.php';

                                // Verify if $gateway is not null
                                if ($gateway) {

                                    $total_to_pay = $price[0]->plan_price;

                                    // Get discount if exists
                                    $discount = get_user_option('user_coupon_value');

                                    if ($discount) {

                                        // Calculate total discount
                                        $total = ($discount / 100) * $price[0]->plan_price;

                                        // Set new price
                                        $total_to_pay = $total_to_pay - $total;
                                    }

                                    if (file_exists(APPPATH . 'payments/' . ucfirst($gateway) . '.php')) {

                                        require_once APPPATH . 'payments/' . ucfirst($gateway) . '.php';

                                        // Call the class
                                        $pay_class = ucfirst(str_replace('-', '_', $gateway));

                                        $get = new $pay_class;

                                        // Verify if the get param pay-return exits
                                        if ($this->CI->input->get('pay-return', TRUE)) {

                                            $pay = $this->CI->input->get('pay-return', TRUE);

                                            if (file_exists(APPPATH . 'payments/' . ucfirst($pay) . '.php')) {

                                                require_once APPPATH . 'payments/' . ucfirst($pay) . '.php';

                                                // Call the class
                                                $pay_class = ucfirst(str_replace('-', '_', $pay));

                                                $get = new $pay_class;

                                                $get->save();
                                            }

                                        } else {

                                            $get->process($plan_id, $total_to_pay, $price[0]->currency_code);

                                        }
                                        
                                        exit();

                                    }

                                } else {

                                    // Delete the user coupon code
                                    $this->CI->user->delete_user_option($this->CI->user_id, 'user_coupon_code');

                                    // Delete the user discount value
                                    $this->CI->user->delete_user_option($this->CI->user_id, 'user_coupon_value');

                                    // Create the classes array variable
                                    $classes = [];

                                    // Get all available payments gateways
                                    foreach (glob(APPPATH . 'payments/*.php') as $filename) {

                                        // Require the payments gateways
                                        require_once $filename;

                                        // Clean the class name
                                        $className = str_replace([APPPATH . 'payments/', '.php'], '', $filename);

                                        // Verify if the payment's gateway is enabled
                                        if (($this->CI->options->check_enabled(strtolower($className)) == FALSE)) {
                                            continue;
                                        }

                                        // Call the class name
                                        $get = new $className();

                                        // Get class info
                                        $classes[] = $get->info();
                                    }

                                    // Set the layout's content
                                    $params = array(
                                        'plan' => $plan_id,
                                        'plann' => $price,
                                        'payments' => $classes
                                    );

                                    // Set views params
                                    set_user_view(
                                        $this->CI->load->ext_view(
                                            MIDRUB_BASE_USER_COMPONENTS_PLANS . 'views',
                                            'gateways',
                                            $params,
                                            true
                                        )
                                    );

                                }

                            } else {

                                if ($this->CI->plans->change_plan($plan_id, $this->CI->user_id)) {

                                    $this->CI->session->set_flashdata('upgrade', $this->CI->lang->line('mm100'));

                                } else {

                                    $this->CI->session->set_flashdata('upgrade', $this->CI->lang->line('mm101'));

                                }

                                // go to plans page
                                redirect('user/plans');

                            }

                        } else {
                            show_404();
                        }

                    } else {
                        show_404();
                    }

                    break;                   

                default:
                    show_404();
                    break;

            }

        } else {

            // Get all plans
            $get_plans = $this->CI->plans->get_all_plans();

            // Get user plan
            $user_plan = $this->CI->plans->get_user_plan($this->CI->user_id);

            // Check if user plan expires soon
            $check_plan = $this->CI->plans->check_if_plan_ended($this->CI->user_id);

            $expires_soon = 0;

            if ($check_plan) {

                if ($check_plan < time() + 432000) {

                    $expires_soon = 1;
                }
            }

            $upgrade = '';

            if ($this->CI->session->flashdata('upgrade')) {

                $upgrade = $this->CI->session->flashdata('upgrade');
            }

            // Prepare params
            $params = array(
                'plans' => $get_plans,
                'user_plan' => $user_plan,
                'expires_soon' => $expires_soon,
                'upgrade' => $upgrade
            );

            // Set views params
            set_user_view(
                $this->CI->load->ext_view(
                    MIDRUB_BASE_USER_COMPONENTS_PLANS . 'views',
                    'main',
                    $params,
                    true
                )
            );
        
        }
        
    }
    
}
