<?php
/**
 * Init Controller
 *
 * This file loads the Upgrade Auth Component
 *
 * @author Scrisoft
 * @package Midrub
 * @since 0.0.7.8
 */

// Define the page namespace
namespace MidrubBase\Auth\Collection\Upgrade\Controllers;

defined('BASEPATH') OR exit('No direct script access allowed');

/*
 * Init class loads the Upgrade Component
 * 
 * @author Scrisoft
 * @package Midrub
 * @since 0.0.7.8
 */
class Init {
    
    /**
     * Class variables
     *
     * @since 0.0.7.8
     */
    protected $CI;

    /**
     * Initialise the Class
     *
     * @since 0.0.7.8
     */
    public function __construct() {
        
        // Get codeigniter object instance
        $this->CI =& get_instance();
        
        // Load the component's language files
        if ( file_exists( MIDRUB_BASE_AUTH_UPGRADE. '/language/' . $this->CI->config->item('language') . '/auth_upgrade_lang.php' ) ) {
            $this->CI->lang->load( 'auth_upgrade', $this->CI->config->item('language'), FALSE, TRUE, MIDRUB_BASE_AUTH_UPGRADE. '/' );
        }
        
    }
    
    /**
     * The public method view loads the settings's template
     * 
     * @since 0.0.7.8
     * 
     * @return void
     */
    public function view() {

        // If session exists, redirect user
        if ( !md_the_user_session() ) {
            redirect('/');
        }

        // Get component's title
        $title = (md_the_single_content_meta('quick_seo_page_title'))?md_the_single_content_meta('quick_seo_page_title'):$this->CI->lang->line('auth_upgrade_page_title');

        // Set page's title
        md_set_the_title($title);


        // Set styles
        md_set_css_urls(array('stylesheet', base_url('assets/base/auth/collection/upgrade/styles/css/styles.css?ver=' . MIDRUB_BASE_AUTH_UPGRADE_VERSION), 'text/css', 'all'));

        // Set javascript links
        md_set_js_urls(array(base_url('assets/base/auth/collection/upgrade/js/main.js?ver=' . MIDRUB_BASE_AUTH_UPGRADE_VERSION)));

        // Verify if meta description exists
        if ( md_the_single_content_meta('quick_seo_meta_description') ) {

            // Set meta description
            md_set_the_meta_description(md_the_single_content_meta('quick_seo_meta_description'));

        }

        // Verify if meta keywords exists
        if ( md_the_single_content_meta('quick_seo_meta_keywords') ) {

            // Set meta keywors
            md_set_the_meta_keywords(md_the_single_content_meta('quick_seo_meta_keywords'));

        }

        // Verify if single page exists
        if ( $this->CI->input->get('p', TRUE) ) {

            switch ( $this->CI->input->get('p', TRUE) ) {

                case 'upgrade':

                    // Set plan's id
                    $plan_id = $this->CI->input->get('plan', TRUE);
                    
                    // Set the gateway
                    $gateway = $this->CI->input->get('gateway', TRUE);
                
                    // Verify if plan exists
                    if ( is_numeric( $plan_id ) ) {

                        // Get plan
                        $plan = $this->CI->plans->get_plan($plan_id);

                        // Verify if plan exists
                        if ( $plan ) {

                            // Get plan price
                            $price = $this->CI->plans->get_plan_price($plan_id);

                            if ( $price ) {

                                // Require the Payments interface
                                require_once APPPATH . 'interfaces/Payments.php';

                                // Verify if $gateway is not null
                                if ($gateway) {

                                    $total_to_pay = $price[0]->plan_price;

                                    // Get discount if exists
                                    $discount = get_user_option('user_coupon_value');

                                    if ($discount) {

                                        // Calculate total discount
                                        $total = ($discount / 100) * $price[0]->plan_price;

                                        // Set new price
                                        $total_to_pay = $total_to_pay - $total;
                                    }

                                    if (file_exists(APPPATH . 'payments/' . ucfirst($gateway) . '.php')) {

                                        require_once APPPATH . 'payments/' . ucfirst($gateway) . '.php';

                                        // Call the class
                                        $pay_class = ucfirst(str_replace('-', '_', $gateway));

                                        $get = new $pay_class;

                                        // Verify if the get param pay-return exits
                                        if ($this->CI->input->get('pay-return', TRUE)) {

                                            $pay = $this->CI->input->get('pay-return', TRUE);

                                            if ( file_exists(APPPATH . 'payments/' . ucfirst($pay) . '.php') ) {

                                                require_once APPPATH . 'payments/' . ucfirst($pay) . '.php';

                                                // Call the class
                                                $pay_class = ucfirst(str_replace('-', '_', $pay));

                                                $get = new $pay_class;

                                                $get->save();
                                            }

                                        } else {

                                            $get->process($plan_id, $total_to_pay, $price[0]->currency_code);

                                        }
                                        
                                        exit();

                                    }

                                } else {
                                    show_404();
                                }

                            }

                        } else {
                            show_404();
                        }

                    } else {
                        show_404();
                    }

                    break;                   

                default:
                    show_404();
                    break;

            }

        } else {

            // Get the user's plan
            $user_plan = get_user_option('plan');

            // Get plan
            $plan = $this->CI->base_model->get_data_where('plans', 'plan_id,plan_price,currency_sign', array('plan_id' => $user_plan));

            // Verify if plan exists
            if (!$plan) {

                // If plan not exists, redirect
                redirect('/');
            }

            // Delete the user coupon code
            $this->CI->user->delete_user_option($this->CI->user_id, 'user_coupon_code');

            // Delete the user discount value
            $this->CI->user->delete_user_option($this->CI->user_id, 'user_coupon_value');

            // Create the classes array variable
            $classes = [];

            // Require the Payments interface
            require_once APPPATH . 'interfaces/Payments.php';

            // Get all available payments gateways
            foreach (glob(APPPATH . 'payments/*.php') as $filename) {

                // Require the payments gateways
                require_once $filename;

                // Clean the class name
                $className = str_replace([APPPATH . 'payments/', '.php'], '', $filename);

                // Verify if the payment's gateway is enabled
                if (!get_option($className)) {
                    continue;
                }

                // Call the class name
                $get = new $className();

                // Get class info
                $classes[] = $get->info();
            }

            // Making temlate and send data to view.
            $this->CI->template['header'] = $this->CI->load->ext_view(MIDRUB_BASE_AUTH_UPGRADE .  '/views/layout', 'header', array(), true);
            $this->CI->template['body'] = $this->CI->load->ext_view(MIDRUB_BASE_AUTH_UPGRADE .  '/views', 'main', array(
                'plan' => $plan,
                'payments' => $classes
            ), true);
            $this->CI->template['footer'] = $this->CI->load->ext_view(MIDRUB_BASE_AUTH_UPGRADE .  '/views/layout', 'footer', array(), true);
            $this->CI->load->ext_view(MIDRUB_BASE_AUTH_UPGRADE . '/views/layout', 'index', $this->CI->template);

        }
        
    }

}
